# -*- coding: utf-8 -*-

import datetime

from django.views.generic import DetailView
from django.conf import settings
from publieditor.content import models


class PublieditorTranslationDetailView(DetailView):
    context_object_name = 'translation_detail_by_slug'
    template_name = 'content/cms_apps/translation_detail.html'
    model = models.TranslationContent

    @staticmethod
    def can_view(user):
        if user.is_staff:
            return True
        today = datetime.date.today()
        if hasattr(user, 'contact') and hasattr(user.contact, 'organization'):
            has_contract = user.contact.organization.contracts.filter(date_end__gte=today).exists()
            if has_contract:
                return True
        return False

    def get_template_names(self):
        # if self.object.content.date_content.date() >= datetime.date.today():
        if not self.can_view(self.request.user):
            self.request.session["blocked_content_slug"] = self.request.path
            return ["content/cms_apps/blocked_translation_detail.html"]
        return super(PublieditorTranslationDetailView, self).get_template_names()

    def get(self, request, *args, **kwargs):
        self.object = self.get_object()
        self.update_object_is_read(request)
        context = self.get_context_data(object=self.object)
        return self.render_to_response(context)

    def get_context_data(self, **kwargs):
        from publieditor.content.models import TranslationContent
        context = super(PublieditorTranslationDetailView, self).get_context_data()
        limit = 10
        language_code = self.request.LANGUAGE_CODE
        corporates, brands = [], []
        # Recupero le notizie collegate per corporate, brand, kind e sector
        kind, sector = self.object.content.kind, self.object.content.sector
        stream = self.object.content.stream
        car_details = self.object.content.car_details.all()
        for car_detail in car_details:
            if car_detail.corporate and car_detail.corporate not in corporates:
                corporates.append(car_detail.corporate)
            if car_detail.brand and car_detail.brand not in brands:
                brands.append(car_detail.brand)
        related_news = dict(
            corporate_news=[{
                'corporate': corporate,
                'news':  TranslationContent.objects.filter(
                    content__car_details__corporate=corporate, language__code__iexact=language_code,
                    content__stream=stream,
                ).exclude(id=self.object.id).order_by('-content__date_content')[:limit]
            } for corporate in corporates],
            brand_news=[{
                'brand': brand,
                'news':  TranslationContent.objects.filter(
                    content__car_details__brand=brand, language__code__iexact=language_code,
                    content__stream=stream,
                ).exclude(id=self.object.id).order_by('-content__date_content')[:limit]
            } for brand in brands]
        )
        related_news['kind_news'] = {
            'kind': kind,
            'news': TranslationContent.objects.filter(
                content__kind=kind, language__code__iexact=language_code,
                content__stream=stream,
            ).exclude(id=self.object.id).order_by('-content__date_content')[:limit]
        } if kind else False
        related_news['sector_news'] = {
            'sector': sector,
            'news': TranslationContent.objects.filter(
                content__sector=sector, language__code__iexact=language_code,
                content__stream=stream,
            ).exclude(id=self.object.id).order_by('-content__date_content')[:limit]
        } if sector else False
        # Creo contesto
        is_open_house = hasattr(self.object.content, 'openhouse')
        context.update({
            'object': self.object,
            'settings': settings,
            'is_open_house': is_open_house,
            'road_test': hasattr(self.object, 'roadtest'),
            'related_news': related_news,
        })
        if is_open_house:
            context.update({
                'open_house': getattr(self.object.content, 'openhouse', None),
            })
        return context

    def update_object_is_read(self, request):
        user = request.user._wrapped if hasattr(request.user, '_wrapped') else request.user
        if user.is_authenticated():
            user_content_settings = models.UserContentSettings.objects.filter(
                user=user,
                translation_content=self.object,
            )
            if user_content_settings:
                user_content_setting = user_content_settings[0]
            else:
                user_content_setting = models.UserContentSettings(
                    user=user,
                    translation_content=self.object,
                )
            user_content_setting.is_read = True
            user_content_setting.save()